@@ -31,6 +31,7 @@
 #include <libosso.h>
 
 #include "he-about-dialog.h"
+#include "he-fullscreen-button.h"
 
 typedef struct _Hercui Hercui;
 struct _Hercui {
@@ -41,6 +42,7 @@ struct _Hercui {
 	GtkWidget *about_button;
 	GtkWidget *start_button;
 	GtkWidget *paste_button;
+	GtkWidget *copy_button;
 	GtkWidget *ipl_button;
 	gchar *chome;
 	gchar *config;
@@ -96,59 +98,59 @@ return FALSE;
 static void
 hui_child_closed(VteTerminal *vt, gpointer user_data)
 {
-gint status;
-
-/* For fucks sake, use new version of software.. disable as vte in maemo is OOOOOOOOOOOOLD */
 #if 0
+gint status;
+/* For fucks sake, use new version of software.. disable as vte in maemo is OOOOOOOOOOOOLD */
 status=vte_terminal_get_child_exit_status(vt);
 if (WIFEXITED(status)) {
 	app.res=WEXITSTATUS(status);
-	app.hpid=0;
+	app.hpid=-1;
 	g_debug("Hercules exited with code: %d", app.res);
 	return;
 }
-g_warning("Huh???");
 #else
-app.hpid=0;
+app.hpid=-1;
 g_debug("Hercules exited");
 #endif
+gtk_widget_show(GTK_WIDGET(app.start_button));
+gtk_widget_hide(GTK_WIDGET(app.copy_button));
+gtk_widget_hide(GTK_WIDGET(app.paste_button));
 }
 
 static gboolean
 hui_quit(GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-if (app.hpid>0) {
+if (app.hpid!=-1) {
 	hildon_banner_show_information(GTK_WIDGET(app.window), "", "Hercules is running, shutdown first.");
-	g_debug("Hercules is running");
 	return TRUE;
 }
 
 return FALSE;
 }
 
-#define URL_HERCUI "http://maemo.tal.org/"
+#define URL_HERCUI "http://maemo.tal.org/index.php/herculesui"
 #define URL_BUGS "http://bugzilla.tal.org/"
 
 static gboolean
 hui_about_cb()
 {
 he_about_dialog_present(GTK_WINDOW(app.window),
-    "HercUI",
-    "hercui",
-    VERSION,
-    "A simple UI for Hercules emulator.",
-    "HercUI is free software, GPLv2\n"
-    "Copyright 2010 Kaj-Michael Lang <milang@tal.org>",
-    URL_HERCUI,
-    URL_BUGS,
-    NULL);
+	"HercUI",
+	"hercui",
+	VERSION,
+	"A simple UI for Hercules emulator.",
+	"HercUI is free software, GPLv2\n"
+	"Copyright 2010 Kaj-Michael Lang <milang@tal.org>",
+	URL_HERCUI,
+	URL_BUGS,
+	NULL);
 return TRUE;
 }
 
 static gboolean
 hui_start_cb()
 {
-if (app.hpid!=0) {
+if (app.hpid!=-1) {
 	hildon_banner_show_information(GTK_WIDGET(app.window), "", "Hercules is already started.");
 	return TRUE;
 }
@@ -156,6 +158,13 @@ if (!hui_choose_hercules_config())
 	return TRUE;
 
 app.hpid=hui_fork_hercules();
+if (app.hpid==-1) {
+	hildon_banner_show_information(GTK_WIDGET(app.window), "", "Failed to start Hercules.");
+	return TRUE;
+}
+gtk_widget_hide(GTK_WIDGET(app.start_button));
+gtk_widget_show(GTK_WIDGET(app.copy_button));
+gtk_widget_show(GTK_WIDGET(app.paste_button));
 return TRUE;
 }
 
@@ -167,6 +176,13 @@ if (app.hpid>0)
 return TRUE;
 }
 
+static gboolean
+hui_copy_cb()
+{
+vte_terminal_paste_clipboard(VTE_TERMINAL(app.vt));
+return TRUE;
+}
+
 static HildonAppMenu *
 hui_menu(void)
 {
@@ -179,17 +195,24 @@ gtk_button_set_label(GTK_BUTTON(app.start_button), "Start Hercules");
 g_signal_connect_after(app.start_button, "clicked", G_CALLBACK(hui_start_cb), NULL);
 hildon_app_menu_append(menu, GTK_BUTTON(app.start_button));
 
-app.paste_button=hildon_gtk_button_new(HILDON_SIZE_AUTO);
-gtk_button_set_label(GTK_BUTTON(app.paste_button), "Paste");
-g_signal_connect_after(app.paste_button, "clicked", G_CALLBACK(hui_paste_cb), NULL);
-hildon_app_menu_append(menu, GTK_BUTTON(app.paste_button));
-
 app.about_button=hildon_gtk_button_new(HILDON_SIZE_AUTO);
 gtk_button_set_label(GTK_BUTTON(app.about_button), "About");
 hildon_app_menu_append(menu, GTK_BUTTON(app.about_button));
 g_signal_connect(G_OBJECT(app.about_button), "clicked", G_CALLBACK(hui_about_cb), NULL);
 
+app.paste_button=hildon_gtk_button_new(HILDON_SIZE_AUTO);
+gtk_button_set_label(GTK_BUTTON(app.paste_button), "Paste");
+g_signal_connect_after(app.paste_button, "clicked", G_CALLBACK(hui_paste_cb), NULL);
+hildon_app_menu_append(menu, GTK_BUTTON(app.paste_button));
+
+app.copy_button=hildon_gtk_button_new(HILDON_SIZE_AUTO);
+gtk_button_set_label(GTK_BUTTON(app.copy_button), "Copy");
+g_signal_connect_after(app.copy_button, "clicked", G_CALLBACK(hui_copy_cb), NULL);
+hildon_app_menu_append(menu, GTK_BUTTON(app.copy_button));
+
 gtk_widget_show_all(GTK_WIDGET(menu));
+gtk_widget_hide(GTK_WIDGET(app.copy_button));
+gtk_widget_hide(GTK_WIDGET(app.paste_button));
 return menu;
 }
 
@@ -211,7 +234,7 @@ hildon_gtk_init(&argc, &argv);
 #else
 gtk_init(&argc, &argv);
 #endif
-g_set_application_name("HerculesUI");
+g_set_application_name("HercuUI");
 gtk_window_set_default_icon_name("hercules");
 
 app.program=HILDON_PROGRAM(hildon_program_get_instance());
@@ -219,6 +242,7 @@ app.program=HILDON_PROGRAM(hildon_program_get_instance());
 #if HILDON_CHECK_VERSION(2,2,0)
 app.window=HILDON_WINDOW(hildon_stackable_window_new());
 hildon_window_set_app_menu(HILDON_WINDOW(app.window), hui_menu());
+he_fullscreen_button_new(GTK_WINDOW(app.window));
 #else
 app.window=HILDON_WINDOW(hildon_window_new());
 hildon_window_set_menu(HILDON_WINDOW(app.window), hui_menu());
@@ -226,7 +250,7 @@ hildon_window_set_menu(HILDON_WINDOW(app.window), hui_menu());
 g_signal_connect(G_OBJECT(app.window), "delete-event", hui_quit, NULL);
 g_signal_connect(G_OBJECT(app.window), "destroy", G_CALLBACK(gtk_main_quit), NULL);
 
-app.hpid=0;
+app.hpid=-1;
 app.vt=vte_terminal_new();
 vte_terminal_set_font_from_string(VTE_TERMINAL(app.vt), "monospace 8");
 g_signal_connect(G_OBJECT(app.vt), "child-exited", hui_child_closed, NULL);
